summaryrefslogtreecommitdiffstats
path: root/src/tools/qdatastream.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:04:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:04:08 -0600
commite02e31c8b9d854cd62cbe9799228f6e08e882773 (patch)
tree53303c981d0b20e03c5a2fc8e959fa74adcb90d1 /src/tools/qdatastream.cpp
parent143f194af098d44bf0dd1ebb29e59f30ce48d523 (diff)
downloadtqt3-e02e31c8b9d854cd62cbe9799228f6e08e882773.tar.gz
tqt3-e02e31c8b9d854cd62cbe9799228f6e08e882773.zip
Sync with latest script
Diffstat (limited to 'src/tools/qdatastream.cpp')
-rw-r--r--src/tools/qdatastream.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/tools/qdatastream.cpp b/src/tools/qdatastream.cpp
index 0c59fdaf8..329bf8f25 100644
--- a/src/tools/qdatastream.cpp
+++ b/src/tools/qdatastream.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing retquirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -180,7 +180,7 @@
default setting is big endian (MSB first). Changing it to little
endian breaks the portability (unless the reader also changes to
little endian). We recommend keeping this setting unless you have
- special retquirements.
+ special requirements.
\target raw
\section1 Reading and writing raw binary data
@@ -405,7 +405,7 @@ void TQDataStream::unsetDevice()
TQDataStream::LittleEndian.
The default setting is big endian. We recommend leaving this
- setting unless you have special retquirements.
+ setting unless you have special requirements.
\sa byteOrder()
*/
@@ -18,7 +18,7 @@
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please